#!/bin/bash
# Copyright Huawei Technologies Co., Ltd. 2019-2020. All rights reserved.

function print_kernel_message()
{
    if [ -e /dev/kmsg ]
    then
        echo $1 > /dev/kmsg
    fi
}

function insmod_kernel_module()
{
    module_file_path=$1
    if [ -e $module_file_path ]
    then
        insmod $module_file_path
        if [ $? -eq 0 ]
        then
            print_kernel_message "kernel module $module_file_path insmod succ"
        else
            print_kernel_message "kernel module $module_file_path insmod failed!ret=$?"
            return 1
        fi
    else
        print_kernel_message "hisi kernel module:$module_file_path not exist"
        return 1
    fi
    return 0
}

function insmod_kernel_modules()
{
    insmod_kernel_module /vendor/lib/modules/plat_1103.ko
    if [ $? -ne 0 ]
    then
        return 1;
    fi
    insmod_kernel_module /vendor/lib/modules/wifi_1103.ko
    if [ $? -ne 0 ]
    then
        return 1;
    fi
    print_kernel_message "insmod all hisi kernel modules succ"
    return 0
}

function load_hisi_kenrel_init_function()
{
    module_file_path=$1
    if [ -e $module_file_path ]
    then
        echo init > $module_file_path
        return_value=`cat $module_file_path`
        if [ "$return_value" = "running" ]
        then
            print_kernel_message "kernel module $module_file_path init succ"
        else
            print_kernel_message "kernel module $module_file_path init failed ret=$return_value"
            return 1
        fi
    else
        print_kernel_message "hisi kernel module:$module_file_path not exist"
        return 1
    fi
    return 0
}

function load_hisi_kenrel_init_functions()
{
    load_hisi_kenrel_init_function /sys/hisys/boot/plat
    if [ $? -ne 0 ]
    then
        return 1;
    fi
    load_hisi_kenrel_init_function /sys/hisys/boot/wifi
    if [ $? -ne 0 ]
    then
        return 1;
    fi
    print_kernel_message "insmod all hisi kernel modules succ"
    return 0
}

function load_drivers()
{
    if [ -d /sys/hisys/boot ]
    then
        print_kernel_message "process hisi build-in step"
        load_hisi_kenrel_init_functions
    else
        print_kernel_message "process hisi modules step"
        insmod_kernel_modules
    fi
    return $?
}

function main_user()
{
    load_drivers
}
#--------------------main-----------------
main_user


