#!/bin/bash
# Copyright Huawei Technologies Co., Ltd. 2019-2020. All rights reserved.
#getlogpath获取log存放路径
function getlogpath()
{
    time=$(date "+%Y%m%d%H%M%S")
    file_path="/vendor/log/bt/"
    dumpName="hcilog"
    #默认log存放路径/vendor/log/bt/

    if [ ! -e "/vendor/log/" ]
    then
        mkdir "/vendor/log/"
    fi
    #如果/vendor/log的log文件夹被删除，则重建/vendor/log

    if [ ! -e $file_path ]
    then
        mkdir $file_path
    fi
    #如果/vendor/log/bt的bt文件夹被删除，则重建/vendor/log/bt

    if [ -e $file_path ]
    then
        hcidump_file_path=$file_path$dumpName$time
    else
        hcidump_file_path="/vendor/hcilog$time"
    fi
    #log命令hcilog+XX年XX月XX日XX时XX分XX秒
}

#deletemax删除old日志
function deletemax()
{
    total_size=`du -b $file_path | awk '{print int($1/1024)}'`
    total_num=`ls -lR $file_path | grep "^-"|wc -l`

    #如果log总内存大于500M或者log文件大于50个，删除5个old
    if [ $total_size -gt $((500*1024*1024)) ] || [ $total_num -gt $((50)) ];
    then
        echo $total_size
        echo $total_num
        cd $file_path
        ls -ltr $file_path | grep -v '总用量' |awk '{print $9}' | head -5 | xargs rm -rf
        echo "deletemax sucss"
    fi
    # grep -v 'total' ：去除ls中显示“总用量”的行,仅适用于中标，深度需重新适配
}

#killHcidump停止本次抓取
function killHcidump()
{
    ID=`ps -ef | grep "hcidump -w /vendor" | grep -v grep | awk '{print $2}'`  #注意此shell脚本的名称，避免自杀
    if [ -z "$ID" ];
    then
        echo "hcilog capture process id is empty, process is not existed,nothong to do"
    else
        echo $ID
        for id in $ID
        do
            kill -9 $id
            echo "killed $id"
        done
    echo "hcidump has killed sucss"
    fi
}

#restartHcidump休眠之后自动重启
function restartHcidump()
{
    ID=`ps -ef | grep "hcidump -w /vendor" | grep -v grep | awk '{print $2}'`
    if [ -z "$ID" ];
    then
        echo "hcilog capture process id is empty, process is not existed, restart capture"
        getlogpath
        echo "$hcidump_file_path restart"
        hcidump -w $hcidump_file_path &
    fi
}

function isBtExist()
{
    hci0=`hciconfig | grep "hci0" | grep -v grep |awk '{print length($0)}'`
    #UP=`hciconfig | grep "UP" |awk '{print length($0)}'`
    #如果蓝牙未注册返回0，否则返回1
    if [ -z "$hci0 " ];
    then
        return 0
    else
        return 1
    fi
}

function main_hcilog()
{
    getlogpath
    echo $hcidump_file_path
    isBtExist
    if [ $? -eq 1 ];
    then
        echo " eq 1, bt is on"
        hcidump -w $hcidump_file_path &
    fi
    while [ 1 ]
    do
        isBtExist
        if [ $? -eq 0 ];
        then
            echo "eq 0, bt is off, donot catch log"
            killHcidump
            sleep 10
            continue
        fi

    #log文件被删除，则重新新建文件抓log
        if [ -e $hcidump_file_path ];
        then
            filesize=`stat -c "%s" $hcidump_file_path`
        else 
           killHcidump
           echo "kill beause filesize is null or zero"
           getlogpath
           hcidump -w $hcidump_file_path &
        fi

    #log文件大于50M，则重新新建文件抓log
        if [ $filesize -gt $((50*1024*1024)) ];
	    then
           killHcidump
           echo "kill beause filesize is big"
           getlogpath
           hcidump -w $hcidump_file_path &
        fi

    #如果log总内存大于指定大小，删除最先的5个，不足5个则全删
        deletemax
        sleep 5
    #如果进程被杀死，则重启进程
        restartHcidump 
    done
}
#--------------------main-----------------
main_hcilog
